### Ulrike Groemping
### August 10, 2023
### accompanying code for report 001/2023

## R version should be at least 4
## otherwise, results based on random numbers will be different

options(knitr.kable.NA = '.')
require(SOAs)
require(knitr)
require(kableExtra)
require(prepplot)

## Example 9 / Table 6
## ----GSOA81load------------------------------------------------------------------------
load("GSOA81seed8278.RData")
## has GSOA81 and pat81 and pat27
## was created with GSOA81strength3.R (also available)
## run time is quite long (about an hour)
hilf <- dim_wt_tab(pat81)
colnames(hilf)[17] <- "GWLP"
class(hilf) <- c(class(hilf), "matrix")

## ----Spat25----------------------------------------------------------------------------
exampleLHDs <- read.csv2("SunEtAl25runs.csv")
D1 <- exampleLHDs[,1:3]  ## uniform
D2 <- exampleLHDs[,4:6]  ## maximin
D3 <- exampleLHDs[,7:9]  ## maxpro
D4 <- exampleLHDs[,10:12]  ## UPD
colnames(D1) <- colnames(D2) <- colnames(D3) <- colnames(D4) <- paste0("V", 1:3)
rownames(D1) <- rownames(D2) <- rownames(D3) <- rownames(D4) <- 1:25
suntab <- rbind("(ref:D1)"=Spattern(D1, 5, maxwt=NULL),
      "(ref:D2)"=Spattern(D2, 5, maxwt=NULL),
      "(ref:D3)"=Spattern(D3, 5, maxwt=NULL),
      "(ref:D4)"=Spattern(D4, 5, maxwt=NULL))
colnames(suntab) <- c("(ref:S1)","(ref:S2)","(ref:S3)","(ref:S4)","(ref:S5)","(ref:S6)")
suntab <- cbind(suntab, ' '=rep(" ",4), '(ref:phip)'=round(c(phi_p(D1),phi_p(D2),phi_p(D3),phi_p(D4)),3))
knitr::kable(suntab, booktabs=TRUE, caption="Stratification patterns and (ref:phip) values of the four 25-level arrays of Sun et al. (2019)")

## ----el1-------------------------------------------------------------------------------
pat81_el1 <- Spattern(L81.3.8, s=3, maxdim=NULL, maxwt=NULL)

## ---- Example 14 --------------------------------
set.seed(8278)
## the 64 level design (in 64 runs)
plan3 <- SOAs(L64.4.6, noptim.rounds = 3, noptim.repeats = 5)
## the 16 level design
plan2 <- plan3%/%4

## the four patterns
pat_16_s4 <- Spattern(plan2,s=4, maxwt=6)
pat_64_s4 <- Spattern(plan3,s=4, maxwt=6)
pat_16_s2 <- Spattern(plan2,s=2, maxwt=12)
pat_64_s2 <- Spattern(plan3,s=2, maxwt=12)

## ------- Figure 1
## fig.cap="The first two columns of the two 64 run designs of Table 10:
## filled dots represent the 16-level design, circles the 64-level design.
## Axis labels: levels of the 16-level design; the corresponding 4 levels
## of the 64-level design are placed centered at these,
## dotted grid lines separate their positions." ----
par(pty="s", cex.axis=0.7)
prepplot(seq(-0.5, 63.5), seq(-0.5,63.5),
                   asp=1,xaxs="i",yaxs="i",xaxt="n",yaxt="n")
points(4*plan2[,1:2]+1.5, pch=16, cex=1.3)
points(plan3[,1:2])
abline(h=seq(-0.5,63.5,4), lwd=1)
abline(v=seq(-0.5,63.5,4), lwd=1)
abline(h=seq(-0.5,63.5,8), lwd=2)
abline(v=seq(-0.5,63.5,8), lwd=2)
abline(h=seq(-0.5,63.5,16), lwd=3)
abline(v=seq(-0.5,63.5,16), lwd=3)
abline(h=seq(-0.5,63.5,1), lwd=0.5, lty=3)
abline(v=seq(-0.5,63.5,1), lwd=0.5, lty=3)
axis(side=1, at=seq(1.5,61.5,4), 0:15, tcl=0, mgp=c(2,0.5,0))
axis(side=2, at=seq(1.5,61.5,4), 0:15, tcl=0, las=1)
axis(side=3, at=seq(1.5,61.5,4), 0:15, tcl=0, mgp=c(2,0.5,0))
axis(side=4, at=seq(1.5,61.5,4), 0:15, tcl=0, mgp=c(2,0.5,0), las=1)

## ---- tables -----------------------
tab1 <- dim_wt_tab(pat_16_s4)
  dn <- dimnames(tab1)
  names(dn) <- NULL
  dimnames(tab1) <- dn
tab1 <- cbind(tab1[,1:6],c(GWLP(plan2)[-1], sum(GWLP(plan2)[-1])))
colnames(tab1)[7] <- "GWLP"

tab2 <- dim_wt_tab(pat_64_s4)
  dn <- dimnames(tab2)
  names(dn) <- NULL
  dimnames(tab2) <- dn
tab2 <- cbind(tab2[,1:6],c(GWLP(plan3)[-1], sum(GWLP(plan3)[-1])))
colnames(tab2)[7] <- "GWLP"

tab3 <- dim_wt_tab(pat_16_s2)
  dn <- dimnames(tab3)
  names(dn) <- NULL
  dimnames(tab3) <- dn
tab3[,13] <- c(GWLP(plan2)[-1], sum(GWLP(plan2)[-1]))
colnames(tab3)[13] <- "GWLP"

tab4 <- dim_wt_tab(pat_64_s2)
  dn <- dimnames(tab4)
  names(dn) <- NULL
  dimnames(tab4) <- dn
tab4[,13] <- c(GWLP(plan3)[-1], sum(GWLP(plan3)[-1]))
colnames(tab4)[13] <- "GWLP"

class(tab3) <- c(class(tab3), "matrix")
class(tab4) <- c(class(tab4), "matrix")

kab1 <- knitr::kable(cbind(tab1[,-7],c(" "),tab3[,-13]),
         booktabs=TRUE, linesep=c(rep("",4),"\\midrule"), align="r")
kab1 <- kableExtra::add_header_above(kab1, header=c(" "=1, "(ref:s)=4"=6, " "=1, "(ref:s)=2"=12))
head1 <- 20
names(head1) <- paste0("16 levels, (ref:phip)=", format(round(phi_p(plan2), 4), nsmall=4))
kab1 <- kableExtra::add_header_above(kab1, header=head1)
kab2 <- knitr::kable(cbind(tab2[,-7],c(" "),tab4[,-13]),
         booktabs=TRUE, linesep=c(rep("",4),"\\midrule"), align="r")
kab2 <- kableExtra::add_header_above(kab2, header=c(" "=1, "(ref:s)=4"=6, " "=1, "(ref:s)=2"=12))
head2 <- 20
names(head2) <- paste0("64 levels, (ref:phip)=", format(round(phi_p(plan3), 4), nsmall=4))
kab2 <- kableExtra::add_header_above(kab2, header=head2)
knitr::kables(list(kab1, kab2), caption="Dimension by weight tables of contributions to stratification pattern, considering (ref:s)=4 and (ref:s)=2, for an SOA with 64~level columns and a version with columns collapsed to 16~levels only. Weights have been limited to 6 or 12, respectively, corresponding to considering up to 4096~strata. Row labels: dimension (ref:d). Column labels: weight (ref:j). Bottom margin: stratification pattern.")
